@@ -4,7 +4,7 @@ def get_version():
     return '%s.%s' % (VERSION[0], VERSION[1])
 
 
-VERSION = (0, 24,)
+VERSION = (0, 25,)
 
 __version__ = get_version()
 __author__ = 'Javier Cordero'
@@ -15,4 +15,11 @@ from .smsfactory import SMSFactory
 
 smsfactory = SMSFactory()
 
+try:
+    from django.utils.module_loading import autodiscover_modules
+    def autodiscover():
+        autodiscover_modules('sms', register_to=smsfactory)
+except ImportError:
+    pass
+
 default_app_config = 'mailfactory_extras.apps.MailFactoryExtrasConfig'
